Security Advisories (10)
CPANSA-Mojolicious-2022-03 (2022-12-10)

Mojo::DOM did not correctly parse <script> tags.

CPANSA-Mojolicious-2021-02 (2021-06-01)

Small sessions could be used as part of a brute-force attack to decode the session secret.

CVE-2021-47208 (2021-03-16)

A bug in format detection can potentially be exploited for a DoS attack.

CVE-2018-25100 (2018-02-13)

Mojo::UserAgent::CookieJar leaks old cookies because of the missing host_only flag on empty domain.

CPANSA-Mojolicious-2015-01 (2015-02-02)

Directory traversal on Windows

CPANSA-Mojolicious-2018-03 (2018-05-19)

Mojo::UserAgent was not checking peer SSL certificates by default.

CVE-2020-36829 (2020-11-10)

Mojo::Util secure_compare can leak the string length. By immediately returning when the two strings are not the same length, the function allows an attacker to guess the length of the secret string using timing attacks.

CPANSA-Mojolicious-2018-02 (2018-05-11)

GET requests with embedded backslashes can be used to access local files on Windows hosts

CPANSA-Mojolicious-2014-01 (2014-10-07)

Context sensitivity of method param could lead to parameter injection attacks.

CVE-2024-58134 (2025-05-03)

Mojolicious versions from 0.999922 for Perl uses a hard coded string, or the application's class name, as a HMAC session secret by default. These predictable default secrets can be exploited to forge session cookies. An attacker who knows or guesses the secret could compute valid HMAC signatures for the session cookie, allowing them to tamper with or hijack another user's session.

NAME

Mojo::Content - HTTP content base class

SYNOPSIS

package Mojo::Content::MyContent;
use Mojo::Base 'Mojo::Content';

sub body_contains  {...}
sub body_size      {...}
sub get_body_chunk {...}

DESCRIPTION

Mojo::Content is an abstract base class for HTTP content based on RFC 7230 and RFC 7231.

EVENTS

Mojo::Content inherits all events from Mojo::EventEmitter and can emit the following new ones.

body

$content->on(body => sub {
  my $content = shift;
  ...
});

Emitted once all headers have been parsed and the body starts.

$content->on(body => sub {
  my $content = shift;
  $content->auto_upgrade(0) if $content->headers->header('X-No-MultiPart');
});

drain

$content->on(drain => sub {
  my ($content, $offset) = @_;
  ...
});

Emitted once all data has been written.

$content->on(drain => sub {
  my $content = shift;
  $content->write_chunk(time);
});

read

$content->on(read => sub {
  my ($content, $bytes) = @_;
  ...
});

Emitted when a new chunk of content arrives.

$content->unsubscribe('read');
$content->on(read => sub {
  my ($content, $bytes) = @_;
  say "Streaming: $bytes";
});

ATTRIBUTES

Mojo::Content implements the following attributes.

auto_relax

my $bool = $content->auto_relax;
$content = $content->auto_relax($bool);

Try to detect when relaxed parsing is necessary.

expect_close

my $bool = $content->expect_close;
$content = $content->expect_close($bool);

Expect a response that is terminated with a connection close.

headers

my $headers = $content->headers;
$content    = $content->headers(Mojo::Headers->new);

Content headers, defaults to a Mojo::Headers object.

max_buffer_size

my $size = $content->max_buffer_size;
$content = $content->max_buffer_size(1024);

Maximum size in bytes of buffer for content parser, defaults to the value of the MOJO_MAX_BUFFER_SIZE environment variable or 262144 (256KB).

max_leftover_size

my $size = $content->max_leftover_size;
$content = $content->max_leftover_size(1024);

Maximum size in bytes of buffer for pipelined HTTP requests, defaults to the value of the MOJO_MAX_LEFTOVER_SIZE environment variable or 262144 (256KB).

relaxed

my $bool = $content->relaxed;
$content = $content->relaxed($bool);

Activate relaxed parsing for responses that are terminated with a connection close.

skip_body

my $bool = $content->skip_body;
$content = $content->skip_body($bool);

Skip body parsing and finish after headers.

METHODS

Mojo::Content inherits all methods from Mojo::EventEmitter and implements the following new ones.

body_contains

my $bool = $content->body_contains('foo bar baz');

Check if content contains a specific string. Meant to be overloaded in a subclass.

body_size

my $size = $content->body_size;

Content size in bytes. Meant to be overloaded in a subclass.

boundary

my $boundary = $content->boundary;

Extract multipart boundary from Content-Type header.

build_body

my $str = $content->build_body;

Render whole body.

build_headers

my $str = $content->build_headers;

Render all headers.

charset

my $charset = $content->charset;

Extract charset from Content-Type header.

clone

my $clone = $content->clone;

Clone content if possible, otherwise return undef.

generate_body_chunk

my $bytes = $content->generate_body_chunk(0);

Generate dynamic content.

get_body_chunk

my $bytes = $content->get_body_chunk(0);

Get a chunk of content starting from a specific position. Meant to be overloaded in a subclass.

get_header_chunk

my $bytes = $content->get_header_chunk(13);

Get a chunk of the headers starting from a specific position.

header_size

my $size = $content->header_size;

Size of headers in bytes.

is_chunked

my $bool = $content->is_chunked;

Check if content is chunked.

is_compressed

my $bool = $content->is_compressed;

Check if content is gzip compressed.

is_dynamic

my $bool = $content->is_dynamic;

Check if content will be dynamically generated, which prevents "clone" from working.

is_finished

my $bool = $content->is_finished;

Check if parser is finished.

is_limit_exceeded

my $bool = $content->is_limit_exceeded;

Check if buffer has exceeded "max_buffer_size".

is_multipart

my $false = $content->is_multipart;

False.

is_parsing_body

my $bool = $content->is_parsing_body;

Check if body parsing started yet.

leftovers

my $bytes = $content->leftovers;

Get leftover data from content parser.

parse

$content
  = $content->parse("Content-Length: 12\x0d\x0a\x0d\x0aHello World!");

Parse content chunk.

parse_body

$content = $content->parse_body('Hi!');

Parse body chunk and skip headers.

progress

my $size = $content->progress;

Size of content already received from message in bytes.

write

$content = $content->write($bytes);
$content = $content->write($bytes => sub {...});

Write dynamic content non-blocking, the optional drain callback will be invoked once all data has been written.

write_chunk

$content = $content->write_chunk($bytes);
$content = $content->write_chunk($bytes => sub {...});

Write dynamic content non-blocking with chunked transfer encoding, the optional drain callback will be invoked once all data has been written.

SEE ALSO

Mojolicious, Mojolicious::Guides, http://mojolicio.us.